summaryrefslogtreecommitdiff
path: root/gl/version-etc.c
diff options
context:
space:
mode:
authorSimon Josefsson <simon@josefsson.org>2009-02-01 11:13:06 +0100
committerSimon Josefsson <simon@josefsson.org>2009-02-01 11:13:06 +0100
commit96e40db00f6343fae0036c47fe86f2e3b2da08a7 (patch)
tree037e84e2072fd9c39a30a7aaae4c470cc17bd674 /gl/version-etc.c
parent8c69e7bd49ea2dfd61f214a00a3f4636465952ff (diff)
downloadgnutls-96e40db00f6343fae0036c47fe86f2e3b2da08a7.tar.gz
Update gnulib files.
Diffstat (limited to 'gl/version-etc.c')
-rw-r--r--gl/version-etc.c18
1 files changed, 16 insertions, 2 deletions
diff --git a/gl/version-etc.c b/gl/version-etc.c
index 6ef1cca70c..2258c2e21d 100644
--- a/gl/version-etc.c
+++ b/gl/version-etc.c
@@ -1,4 +1,4 @@
/* Utility to help print --version output in a consistent format.
Copyright (C) 1999-2009 Free Software Foundation, Inc.
This program is free software: you can redistribute it and/or modify
@@ -66,7 +66,7 @@ version_etc_va (FILE *stream,
fputs (_("\
\n\
-License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n\
This is free software: you are free to change and redistribute it.\n\
There is NO WARRANTY, to the extent permitted by law.\n\
\n\
@@ -170,3 +170,17 @@ version_etc (FILE *stream,
va_start (authors, version);
version_etc_va (stream, command_name, package, version, authors);
}
+
+void
+emit_bug_reporting_address (void)
+{
+ /* TRANSLATORS: The placeholder indicates the bug-reporting address
+ for this package. Please add _another line_ saying
+ "Report translation bugs to <...>\n" with the address for translation
+ bugs (typically your translation team's web or email address). */
+ printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+ printf (_("%s home page: <http://www.gnu.org/software/%s/>.\n"),
+ PACKAGE_NAME, PACKAGE);
+ fputs (_("General help using GNU software: <http://www.gnu.org/gethelp/>.\n"),
+ stdout);
+}
@@ -1,4 +1,4 @@
-/* Utility to help print --version output in a consistent format.
+/* Print --version and bug-reporting information in a consistent format.
Copyright (C) 1999-2009 Free Software Foundation, Inc.
This program is free software: you can redistribute it and/or modify